@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -27,6 +27,7 @@ from ..core.enums import (
     LatLon,
     LocationType,
     NumeralLanguage,
+    ResolutionType,
     RoundingFunction,
 )
 from ..core.has_props import abstract
@@ -41,6 +42,7 @@ from ..core.properties import (
     Int,
     List,
     Nullable,
+    Seq,
     String,
 )
 from ..core.validation import error
@@ -636,7 +638,14 @@ class DatetimeTickFormatter(TickFormatter):
     years = String(help=_DATETIME_TICK_FORMATTER_HELP("``years``"),
                    default="%Y").accepts(List(String), _deprecated_datetime_list_format)
 
-    strip_leading_zeros = Bool(default=True, help="Whether to strip any leading zeros in the formatted ticks")
+    strip_leading_zeros = Either(Bool, Seq(Enum(ResolutionType)), default=False, help="""
+    Whether to strip any leading zeros in the formatted ticks.
+
+    Valid values are:
+    * ``True`` or ``False`` (default) to set stripping across all resolutions.
+    * A sequence of resolution types, e.g. ``["microseconds", "milliseconds"]``, to enable
+    scale-dependent stripping of leading zeros.
+    """)
 
     context = Nullable(Either(String, Instance("bokeh.models.formatters.DatetimeTickFormatter")), default=None, help="""
     A format for adding context to the tick or ticks specified by ``context_which``.
